@@ -23,7 +23,7 @@ from typing import List, Optional
 import click
 from click_plugins import with_plugins
 from pkg_resources import iter_entry_points
-from tqdm import tqdm
+from tqdm.autonotebook import tqdm
 
 from .canonicalize import to_bel_script
 from .constants import get_cache_connection
