@@ -550,9 +550,5 @@ belns_encodings = {
 
 BELNS_ENCODING_STR = ''.join(sorted(belns_encodings))
 
-PYBEL_REMOTE_HOST = 'PYBEL_REMOTE_HOST'
-PYBEL_REMOTE_USER = 'PYBEL_REMOTE_USER'
-PYBEL_REMOTE_PASSWORD = 'PYBEL_REMOTE_PASSWORD'  # noqa: S105
-
 PYBEL_PUBMED = '29048466'
 SET_CITATION_FMT = 'SET Citation = {{"{}", "{}"}}'
