@@ -9,13 +9,12 @@ from typing import Iterable, List, Optional, Set, Union
 
 from .exc import InferCentralDogmaException, ListAbundanceEmptyException, ReactionEmptyException
 from ..constants import (
-    ABUNDANCE, BEL_DEFAULT_NAMESPACE, BIOPROCESS, COMPLEX, COMPOSITE, CONCEPT, FRAGMENT, FRAGMENT_DESCRIPTION,
-    FRAGMENT_MISSING, FRAGMENT_START, FRAGMENT_STOP, FUNCTION, FUSION, FUSION_MISSING, FUSION_REFERENCE, FUSION_START,
-    FUSION_STOP, GENE, GMOD, HGVS, KIND, MEMBERS, MIRNA, PARTNER_3P, PARTNER_5P, PATHOLOGY, PMOD, PMOD_CODE, PMOD_ORDER,
-    PMOD_POSITION, POPULATION, PRODUCTS, PROTEIN, RANGE_3P, RANGE_5P, REACTANTS, REACTION, RNA, VARIANTS, XREFS,
-    rev_abundance_labels,
+    ABUNDANCE, BIOPROCESS, COMPLEX, COMPOSITE, CONCEPT, FRAGMENT, FRAGMENT_DESCRIPTION, FRAGMENT_MISSING,
+    FRAGMENT_START, FRAGMENT_STOP, FUNCTION, FUSION, FUSION_MISSING, FUSION_REFERENCE, FUSION_START, FUSION_STOP, GENE,
+    GMOD, HGVS, KIND, MEMBERS, MIRNA, PARTNER_3P, PARTNER_5P, PATHOLOGY, PMOD, PMOD_CODE, PMOD_ORDER, PMOD_POSITION,
+    POPULATION, PRODUCTS, PROTEIN, RANGE_3P, RANGE_5P, REACTANTS, REACTION, RNA, VARIANTS, XREFS, rev_abundance_labels,
 )
-from ..language import Entity
+from ..language import Entity, gmod_mappings, pmod_mappings
 
 __all__ = [
     # Base Classes
@@ -116,6 +115,15 @@ class BaseEntity(dict, metaclass=ABCMeta):
     def __str__(self):  # noqa: D105
         return self.as_bel()
 
+    @property
+    def safe_label(self) -> str:
+        """Get the safe label for the node (name or BEL)."""
+        if isinstance(self, CentralDogma) and self.variants:
+            return self.as_bel()
+        if isinstance(self, BaseConcept):
+            return self.curie
+        return self.as_bel()
+
 
 class BaseConcept(dict):
     """A dictionary containing a concept entry."""
@@ -369,7 +377,7 @@ class EntityVariant(Variant, BaseConcept):
         super().__init__(kind=self.function)
 
         self[CONCEPT] = Entity(
-            namespace=(namespace or BEL_DEFAULT_NAMESPACE),
+            namespace=namespace,
             name=name,
             identifier=identifier,
         )
@@ -420,6 +428,10 @@ class ProteinModification(EntityVariant):
         >>>                     identifier='0006468', code='Thr', position=308)
 
         """
+        if name and not namespace and not identifier:
+            x = pmod_mappings[name]['xrefs'][0]
+            namespace, identifier, name = x.namespace, x.identifier, x.name
+
         super().__init__(
             name=name,
             namespace=namespace,
@@ -447,24 +459,49 @@ class ProteinModification(EntityVariant):
 
 
 class GeneModification(EntityVariant):
-    """Build a gene modification variant dictionary.
-
-    Either the name or the identifier must be used. If the namespace is omitted, it is assumed that a name is
-    specified from the BEL default namespace.
-
-    Example from BEL default namespace:
-
-    >>> from pybel.dsl import GeneModification
-    >>> GeneModification(name='Me')
-
-    Example from custom namespace:
-
-    >>> from pybel.dsl import GeneModification
-    >>> GeneModification(name='DNA methylation', namespace='GO', identifier='0006306',)
-    """
+    """Build a gene modification variant dictionary."""
 
     function = GMOD
 
+    def __init__(
+        self,
+        name: str,
+        namespace: Optional[str] = None,
+        identifier: Optional[str] = None,
+        xrefs: Optional[List[Entity]] = None,
+    ) -> None:
+        """Build a protein modification variant data dictionary.
+
+        :param name: The name of the modification
+        :param namespace: The namespace to which the name of this modification belongs
+        :param identifier: The identifier of the name of the modification
+        :param xrefs: Alternative database xrefs
+
+        Either the name or the identifier must be used. If the namespace is omitted, it is assumed that a name is
+        specified from the BEL default namespace.
+
+        Example from BEL default namespace:
+
+        >>> from pybel.dsl import GeneModification
+        >>> GeneModification(name='Me')
+
+        Example from custom namespace:
+
+        >>> from pybel.dsl import GeneModification
+        >>> GeneModification(name='DNA methylation', namespace='GO', identifier='0006306')
+
+        """
+        if name and not namespace and not identifier:
+            x = gmod_mappings[name]['xrefs'][0]
+            namespace, identifier, name = x.namespace, x.identifier, x.name
+
+        super().__init__(
+            name=name,
+            namespace=namespace,
+            identifier=identifier,
+            xrefs=xrefs,
+        )
+
     def as_bel(self, use_identifiers: bool = True) -> str:
         """Return this gene modification variant as a BEL string."""
         if use_identifiers and self.entity.identifier and self.entity.name:
@@ -708,6 +745,17 @@ def _entity_list_as_bel(entities: Iterable[BaseEntity], use_identifiers: bool =
     )
 
 
+def _help_named(self, namespace, identifier, name, xrefs):
+    if namespace:
+        self[CONCEPT] = Entity(
+            namespace=namespace,
+            name=name,
+            identifier=identifier,
+        )
+        if xrefs:
+            self[XREFS] = xrefs
+
+
 class Reaction(BaseEntity):
     """Build a reaction node."""
 
@@ -717,17 +765,26 @@ class Reaction(BaseEntity):
         self,
         reactants: Union[BaseAbundance, Iterable[BaseAbundance]],
         products: Union[BaseAbundance, Iterable[BaseAbundance]],
+        namespace: Optional[str] = None,
+        name: Optional[str] = None,
+        identifier: Optional[str] = None,
+        xrefs: Optional[List[Entity]] = None,
     ) -> None:
         """Build a reaction node.
 
         :param reactants: A list of PyBEL node data dictionaries representing the reactants
         :param products: A list of PyBEL node data dictionaries representing the products
+        :param namespace: The namespace from which the name originates
+        :param name: The name of the complex
+        :param identifier: The identifier in the namespace in which the name originates
+        :param xrefs: Alternate identifiers for the entity if it is named
 
         >>> from pybel.dsl import Reaction, Protein, Abundance
         >>> Reaction([Protein(namespace='HGNC', name='KNG1')], [Abundance(namespace='CHEBI', name='bradykinin')])
 
         """
         super().__init__()
+        _help_named(self, namespace=namespace, identifier=identifier, name=name, xrefs=xrefs)
 
         if isinstance(reactants, BaseEntity):
             reactants = [reactants]
@@ -739,7 +796,7 @@ class Reaction(BaseEntity):
         else:
             products = sorted(products, key=_as_bel)
 
-        if not reactants and not products:
+        if not reactants and not products and not namespace:
             raise ReactionEmptyException('Reaction can not be instantiated with an empty members list.')
 
         self.update({
@@ -822,14 +879,7 @@ class ComplexAbundance(ListAbundance):
         :param xrefs: Alternate identifiers for the entity if it is named
         """
         super().__init__(members=members)
-        if namespace:
-            self[CONCEPT] = Entity(
-                namespace=namespace,
-                name=name,
-                identifier=identifier,
-            )
-            if xrefs:
-                self[XREFS] = xrefs
+        _help_named(self, namespace=namespace, identifier=identifier, name=name, xrefs=xrefs)
 
     @property
     def entity(self) -> Optional[Entity]:  # noqa:D401
