@@ -54,11 +54,10 @@ from typing import Any, Collection, Mapping, Optional, Tuple, Union
 
 import pyobo
 from protmapper.uniprot_client import get_id_from_mnemonic, get_mnemonic
-from pyobo.extract import get_id_name_mapping, get_name_id_mapping
-from pyobo.getters import MissingOboBuild, NoOboFoundry
+from pyobo.getters import NoBuild
 from pyobo.identifier_utils import normalize_prefix
 from pyobo.xrefdb.sources.famplex import get_remapping
-from tqdm import tqdm
+from tqdm.autonotebook import tqdm
 
 from pybel.constants import (
     ACTIVITY, ANNOTATIONS, CONCEPT, EFFECT, FROM_LOC, FUSION, GMOD, IDENTIFIER, KIND, LOCATION,
@@ -361,8 +360,8 @@ def _handle_identifier_not_name(
         return True
 
     try:
-        id_name_mapping = get_id_name_mapping(prefix)
-    except (NoOboFoundry, MissingOboBuild):
+        id_name_mapping = pyobo.api.names.get_id_name_mapping(prefix)
+    except NoBuild:
         return False
 
     if id_name_mapping is None:
@@ -445,8 +444,8 @@ def _handle_name_and_not_identifier(
         return False
 
     try:
-        id_name_mapping = get_name_id_mapping(prefix)
-    except (NoOboFoundry, MissingOboBuild) as e:
+        id_name_mapping = pyobo.api.names.get_name_id_mapping(prefix)
+    except NoBuild as e:
         logger.warning('could not get namespace %s - %s', prefix, e)
         return False
 
