@@ -5,11 +5,12 @@
 This module contains mappings between PyBEL's internal constants and BEL language keywords.
 """
 
+import warnings
 from typing import Optional
 
 from .constants import (
-    ABUNDANCE, BEL_DEFAULT_NAMESPACE, BIOPROCESS, CELL_SURFACE, COMPLEX, COMPOSITE, EXTRACELLULAR, GENE, IDENTIFIER,
-    INTRACELLULAR, MIRNA, NAME, NAMESPACE, PATHOLOGY, PROTEIN, RNA, TRANSCRIBED_TO, TRANSLATED_TO,
+    ABUNDANCE, BIOPROCESS, CELL_SURFACE, COMPLEX, COMPOSITE, EXTRACELLULAR, GENE, IDENTIFIER, INTRACELLULAR, MIRNA,
+    NAME, NAMESPACE, PATHOLOGY, PROTEIN, RNA, TRANSCRIBED_TO, TRANSLATED_TO,
 )
 from .utils import ensure_quotes
 
@@ -50,9 +51,9 @@ class Entity(dict):
 
         if identifier is not None:
             if not isinstance(identifier, str):
-                raise TypeError('identifier should be a string {}'.format(identifier))
+                raise TypeError(f'identifier should be a string. Got {type(identifier)} {identifier}')
             if not identifier:
-                raise ValueError('identifier shold be non-empty')
+                raise ValueError('identifier should be non-empty')
             self[IDENTIFIER] = identifier
 
     @property
@@ -73,9 +74,6 @@ class Entity(dict):
     @property
     def curie(self) -> str:
         """Return this entity as a CURIE."""
-        if self[NAMESPACE] == BEL_DEFAULT_NAMESPACE:
-            return self[NAME]
-
         return '{}:{}'.format(
             self.namespace,
             ensure_quotes(self.identifier if self.identifier else self.name),
@@ -91,8 +89,18 @@ class Entity(dict):
         )
 
     def __str__(self):  # noqa: D105
-        return self.curie
+        return self.obo if self.identifier and self.name else self.curie
 
+    def __hash__(self) -> int:
+        return hash((self.namespace, self.identifier, self.name))
+
+
+text_location_labels = {
+    'Abstract': Entity(namespace='iao', identifier='0000315', name='abstract'),
+    'Review': Entity(namespace='iao', identifier='0000311', name='publication'),  # sue me
+    'Results': Entity(namespace='iao', identifier='0000318', name='results section'),
+    'Legend': Entity(namespace='sio', identifier='000468 ', name='legend'),
+}
 
 #: A dictionary of activity labels used in the ma() function in activity(p(X), ma(Y))
 activity_labels = {
@@ -125,6 +133,7 @@ activity_labels = {
 
 #: Maps the default BEL molecular activities to Gene Ontology Molecular Functions
 activity_mapping = {
+    'act': Entity(namespace='go', name='molecular function', identifier='0003674'),
     'cat': Entity(namespace='go', name='catalytic activity', identifier='0003824'),
     'chap': Entity(namespace='go', name='protein binding involved in protein folding', identifier='0044183'),
     'gtp': Entity(namespace='go', name='GTP binding', identifier='0005525'),
@@ -149,12 +158,15 @@ activities = list(activity_labels.keys())
 
 cytoplasm = Entity(name='cytoplasm', namespace='go', identifier='0005737')
 nucleus = Entity(name='nucleus', namespace='go', identifier='0005634')
+intracellular = Entity(name='intracellular', namespace='go', identifier='0005622')
+extracellular = Entity(name='extracellular space', namespace='go', identifier='0005615')
+cell_surface = Entity(name='cell surface', namespace='go', identifier='0009986')
 
 #: Maps the default BEL cellular components to Gene Ontology Cellular Components
 compartment_mapping = {
-    INTRACELLULAR: Entity(name='intracellular', namespace='go', identifier='0005622'),
-    EXTRACELLULAR: Entity(name='extracellular space', namespace='go', identifier='0005615'),
-    CELL_SURFACE: Entity(name='cell surface', namespace='go', identifier='0009986'),
+    INTRACELLULAR: intracellular,
+    EXTRACELLULAR: extracellular,
+    CELL_SURFACE: cell_surface,
     'cytoplasm': cytoplasm,
     'nucleus': nucleus,
 }
@@ -550,5 +562,40 @@ gmod_mappings = {
     },
 }
 
-BEL_DEFAULT_NAMESPACE_VERSION = '2.1.1'
-BEL_DEFAULT_NAMESPACE_URL = 'http://openbel.org/2.1.1.belns'  # just needs something unique... will change later
+
+class CitationDict(Entity):
+    """A dictionary describing a citation."""
+
+    def __init__(self, namespace: str, identifier: str, *, name: Optional[str] = None, **kwargs):
+        super().__init__(namespace=namespace, identifier=identifier, name=name)
+        self.update(kwargs)
+
+
+def citation_dict(
+    *,
+    namespace: Optional[str] = None,
+    db: Optional[str] = None,
+    identifier: Optional[str] = None,
+    db_id: Optional[str] = None,
+    name: Optional[str] = None,
+    **kwargs,
+) -> CitationDict:
+    """Make a citation dictionary."""
+    if namespace and db:
+        raise ValueError('can not specify both namespace and db')
+    if identifier and db_id:
+        raise ValueError('can not specify both identifier and db_id')
+    if db:
+        warnings.warn(
+            'usage of keyword argument `db` in citation_dict() should be replaced with `namespace`. '
+            'Will be removed in PyBEL 16.', DeprecationWarning,
+        )
+        namespace = db
+    if db_id:
+        warnings.warn(
+            'usage of keyword argument `db_id` in citation_dict() should be replaced with `identifier`. '
+            'Will be removed in PyBEL 16.', DeprecationWarning,
+        )
+        identifier = db_id
+
+    return CitationDict(namespace=namespace, identifier=identifier, name=name, **kwargs)
