@@ -12,13 +12,13 @@ from sqlalchemy import (
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import backref, relationship
 
+from .. import constants as pc
 from ..constants import (
-    CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_DB, CITATION_DB_NAME, CITATION_FIRST_AUTHOR,
-    CITATION_IDENTIFIER, CITATION_JOURNAL, CITATION_LAST_AUTHOR, CITATION_PAGES, CITATION_TYPE_PUBMED, CITATION_VOLUME,
-    EVIDENCE, IDENTIFIER, METADATA_AUTHORS, METADATA_CONTACT, METADATA_COPYRIGHT, METADATA_DESCRIPTION,
-    METADATA_DISCLAIMER, METADATA_LICENSES, METADATA_NAME, METADATA_VERSION, NAME, NAMESPACE,
+    CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_FIRST_AUTHOR, CITATION_JOURNAL, CITATION_LAST_AUTHOR, CITATION_PAGES, CITATION_VOLUME, EVIDENCE, IDENTIFIER, METADATA_AUTHORS, METADATA_CONTACT, METADATA_COPYRIGHT, METADATA_DESCRIPTION, METADATA_DISCLAIMER, METADATA_LICENSES, METADATA_NAME, METADATA_VERSION, NAME, NAMESPACE,
 )
-from ..io.gpickle import from_bytes, to_bytes
+from ..io.gpickle import from_bytes_gz, to_bytes_gz
+from ..language import CitationDict, Entity
+from ..struct.graph import BELGraph
 from ..tokens import parse_result_to_dsl
 
 __all__ = [
@@ -115,7 +115,7 @@ class Namespace(Base):
     is_annotation = Column(Boolean)
 
     def __str__(self):
-        return self.keyword
+        return f'[id={self.id}] {self.keyword}'
 
     def get_term_to_encodings(self) -> Mapping[Tuple[Optional[str], str], str]:
         """Return the term (db, id, name) to encodings from this namespace."""
@@ -153,7 +153,7 @@ class NamespaceEntry(Base):
     id = Column(Integer, primary_key=True)
 
     name = Column(
-        String(1023), index=True, nullable=False,
+        String(1023), index=True, nullable=True,
         doc='Name that is defined in the corresponding namespace definition file',
     )
     identifier = Column(String(255), index=True, nullable=True, doc='The database accession number')
@@ -191,7 +191,7 @@ class NamespaceEntry(Base):
         return cls.name.contains(name_query)
 
     def __str__(self):
-        return '[{namespace_id}]{namespace_name}:[{identifier}]{name}'.format(
+        return '[id={namespace_id}] {namespace_name}:{identifier} ! {name}'.format(
             namespace_id=self.namespace.id,
             namespace_name=self.namespace.keyword,
             identifier=self.identifier,
@@ -291,19 +291,13 @@ class Network(Base):
     def __str__(self):
         return repr(self)
 
-    def as_bel(self):
-        """Get this network and loads it into a :class:`BELGraph`.
+    def as_bel(self) -> BELGraph:
+        """Get this network and loads it into a :class:`BELGraph`."""
+        return from_bytes_gz(self.blob)
 
-        :rtype: pybel.BELGraph
-        """
-        return from_bytes(self.blob)
-
-    def store_bel(self, graph):
-        """Insert a BEL graph.
-
-        :param pybel.BELGraph graph: A BEL Graph
-        """
-        self.blob = to_bytes(graph)
+    def store_bel(self, graph: BELGraph):
+        """Insert a BEL graph."""
+        self.blob = to_bytes_gz(graph)
 
 
 class Node(Base):
@@ -392,6 +386,9 @@ class Author(Base):
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return f'Author(name="{self.name}")'
+
 
 class Citation(Base):
     """The information about the citations that are used to prove a specific relation are stored in this table."""
@@ -403,6 +400,7 @@ class Citation(Base):
     db = Column(String(16), nullable=False, doc='Type of the stored publication e.g. PubMed')
     db_id = Column(String(255), nullable=False, doc='Reference identifier of the publication e.g. PubMed_ID')
 
+    article_type = Column(Text, nullable=True, doc='Type of the publication')
     title = Column(Text, nullable=True, doc='Title of the publication')
     journal = Column(Text, nullable=True, doc='Journal name')
     volume = Column(Text, nullable=True, doc='Volume of the journal')
@@ -428,7 +426,7 @@ class Citation(Base):
     @property
     def is_pubmed(self) -> bool:
         """Return if this is a PubMed citation."""
-        return CITATION_TYPE_PUBMED == self.db
+        return self.db == 'pubmed'
 
     @property
     def is_enriched(self) -> bool:
@@ -441,16 +439,17 @@ class Citation(Base):
         :param bool include_id: If true, includes the model identifier
         :return: Citation dictionary for the recreation of a :class:`BELGraph`.
         """
-        result = {
-            CITATION_DB: self.db,
-            CITATION_IDENTIFIER: self.db_id,
-        }
+        result = CitationDict(
+            namespace=self.db,
+            identifier=self.db_id,
+            name=self.title,
+        )
 
         if include_id:
             result['id'] = self.id
 
         if self.title:
-            result[CITATION_DB_NAME] = self.title
+            result[NAME] = self.title
 
         if self.journal:
             result[CITATION_JOURNAL] = self.journal
@@ -470,6 +469,9 @@ class Citation(Base):
         if self.last:
             result[CITATION_LAST_AUTHOR] = self.last.name
 
+        if self.article_type:
+            result[pc.CITATION_ARTICLE_TYPE] = self.article_type
+
         if self.authors:
             result[CITATION_AUTHORS] = sorted(
                 author.name
@@ -603,11 +605,8 @@ class Edge(Base):
 
         return result
 
-    def insert_into_graph(self, graph):
-        """Insert this edge into a BEL graph.
-
-        :param pybel.BELGraph graph: A BEL graph
-        """
+    def insert_into_graph(self, graph: BELGraph) -> str:
+        """Insert this edge into a BEL graph."""
         u = self.source.as_bel()
         v = self.target.as_bel()
 
