@@ -3,10 +3,11 @@
 """Functions for selecting by the neighborhoods of nodes."""
 
 import itertools as itt
-from typing import Iterable
+from typing import Iterable, Optional
 
+from ...graph import BELGraph
 from ...pipeline import transformation
-from ...utils import update_metadata, update_node_helper
+from ...utils import update_metadata
 from ....dsl import BaseEntity
 
 __all__ = [
@@ -15,30 +16,25 @@ __all__ = [
 
 
 @transformation
-def get_subgraph_by_neighborhood(graph, nodes: Iterable[BaseEntity]):
+def get_subgraph_by_neighborhood(graph: BELGraph, nodes: Iterable[BaseEntity]) -> Optional[BELGraph]:
     """Get a BEL graph around the neighborhoods of the given nodes.
 
     Returns none if no nodes are in the graph.
 
-    :param pybel.BELGraph graph: A BEL graph
+    :param graph: A BEL graph
     :param nodes: An iterable of BEL nodes
     :return: A BEL graph induced around the neighborhoods of the given nodes
-    :rtype: Optional[pybel.BELGraph]
     """
     node_set = set(nodes)
 
     if not any(node in graph for node in node_set):
         return
 
-    rv = graph.__class__()
+    rv = graph.child()
     rv.add_edges_from(
         itt.chain(
             graph.in_edges(nodes, keys=True, data=True),
             graph.out_edges(nodes, keys=True, data=True),
         ),
     )
-
-    update_node_helper(graph, rv)
-    update_metadata(graph, rv)
-
     return rv
