@@ -6,11 +6,10 @@ from uuid import uuid4
 
 from requests.compat import urlparse
 
-from ..constants import BEL_DEFAULT_NAMESPACE
 from ..manager import Manager
 from ..manager.models import Namespace, NamespaceEntry
 from ..struct import BELGraph
-from ..struct.summary import get_annotation_values_by_annotation
+from ..struct.summary import get_annotation_values_by_annotation, iter_annotation_value_pairs
 from ..struct.summary.node_summary import get_names
 
 _FRAUNHOFER_RESOURCES = 'https://owncloud.scai.fraunhofer.de/index.php/s/JsfpQvkdx3Y5EMx/download?path='
@@ -34,9 +33,6 @@ def n() -> str:
 def make_dummy_namespaces(manager: Manager, graph: BELGraph) -> None:
     """Make dummy namespaces for the test."""
     for keyword, names in get_names(graph).items():
-        if keyword == BEL_DEFAULT_NAMESPACE:
-            continue
-
         graph.namespace_url[keyword] = url = n()
 
         namespace = Namespace(keyword=keyword, url=url)
@@ -51,16 +47,15 @@ def make_dummy_namespaces(manager: Manager, graph: BELGraph) -> None:
 
 def make_dummy_annotations(manager: Manager, graph: BELGraph):
     """Make dummy annotations for the test."""
-    annotation_names = get_annotation_values_by_annotation(graph)
+    namespaces = {}
+    for keyword, entity in iter_annotation_value_pairs(graph):
+        namespace = namespaces.get(keyword)
+        if namespace is None:
+            graph.annotation_url[keyword] = url = n()
+            namespace = Namespace(keyword=keyword, url=url, is_annotation=True)
+            manager.session.add(namespace)
 
-    for keyword, names in annotation_names.items():
-        graph.annotation_url[keyword] = url = n()
-
-        namespace = Namespace(keyword=keyword, url=url, is_annotation=True)
-        manager.session.add(namespace)
-
-        for name in names:
-            entry = NamespaceEntry(name=name, namespace=namespace)
-            manager.session.add(entry)
+        entry = NamespaceEntry(name=entity.name, identifier=entity.identifier, namespace=namespace)
+        manager.session.add(entry)
 
     manager.session.commit()
