@@ -8,11 +8,11 @@ import unittest
 
 from pybel import BELGraph
 from pybel.constants import (
-    ABUNDANCE, ACTIVITY, BEL_DEFAULT_NAMESPACE, BIOPROCESS, COMPLEX, COMPOSITE, CONCEPT, DEGRADATION,
+    ABUNDANCE, ACTIVITY, BIOPROCESS, CELL_SECRETION, CELL_SURFACE_EXPRESSION, COMPLEX, COMPOSITE, CONCEPT, DEGRADATION,
     DIRECTLY_INCREASES, DIRTY, EFFECT, FRAGMENT, FROM_LOC, FUNCTION, FUSION, FUSION_MISSING, FUSION_REFERENCE,
     FUSION_START, FUSION_STOP, GENE, HAS_VARIANT, HGVS, IDENTIFIER, KIND, LOCATION, MEMBERS, MIRNA, MODIFIER, NAME,
-    NAMESPACE, OBJECT, PARTNER_3P, PARTNER_5P, PART_OF, PATHOLOGY, POPULATION, PRODUCTS, PROTEIN, RANGE_3P, RANGE_5P,
-    REACTANTS, REACTION, RELATION, RNA, SUBJECT, TARGET, TO_LOC, TRANSLOCATION, VARIANTS,
+    NAMESPACE, PARTNER_3P, PARTNER_5P, PART_OF, PATHOLOGY, POPULATION, PRODUCTS, PROTEIN, RANGE_3P, RANGE_5P, REACTANTS,
+    REACTION, RELATION, RNA, SOURCE, TARGET, TARGET_MODIFIER, TO_LOC, TRANSLOCATION, VARIANTS,
 )
 from pybel.dsl import (
     Fragment, Population, abundance, bioprocess, cell_surface_expression, complex_abundance, composite_abundance,
@@ -20,9 +20,9 @@ from pybel.dsl import (
     protein_fusion, reaction, rna, rna_fusion, secretion, translocation,
 )
 from pybel.dsl.namespaces import hgnc
-from pybel.language import Entity
+from pybel.exceptions import MalformedTranslocationWarning
+from pybel.language import Entity, activity_mapping
 from pybel.parser import BELParser
-from pybel.parser.exc import MalformedTranslocationWarning
 from pybel.parser.parse_bel import modifier_po_to_dict
 from tests.constants import TestTokenParserBase, assert_has_edge, assert_has_node, update_provenance
 
@@ -250,7 +250,7 @@ class TestGene(TestTokenParserBase):
 
         expected_node = gene('HGNC', 'AKT1', variants=gmod('Me'))
         self.assert_has_node(expected_node)
-        self.assertEqual('g(HGNC:AKT1, gmod(Me))', self.graph.node_to_bel(expected_node))
+        self.assertEqual('g(HGNC:AKT1, gmod(go:0006306 ! "DNA methylation"))', self.graph.node_to_bel(expected_node))
 
         parent = gene('HGNC', 'AKT1')
         self.assert_has_node(parent)
@@ -748,7 +748,10 @@ class TestProtein(TestTokenParserBase):
         parent = protein('HGNC', 'AKT1')
         node = parent.with_variants([hgvs('p.Ala127Tyr'), pmod('Ph', code='Ser')])
         self.assert_has_node(node)
-        self.assertEqual('p(HGNC:AKT1, pmod(Ph, Ser), var("p.Ala127Tyr"))', self.graph.node_to_bel(node))
+        self.assertEqual(
+            'p(HGNC:AKT1, pmod(go:0006468 ! "protein phosphorylation", Ser), var("p.Ala127Tyr"))',
+            self.graph.node_to_bel(node),
+        )
 
         self.assert_has_node(parent)
         self.assert_has_edge(parent, node, relation=HAS_VARIANT)
@@ -925,7 +928,10 @@ class TestProtein(TestTokenParserBase):
         parent = protein('HGNC', 'AKT1')
         expected_node = parent.with_variants(pmod('Ph', code='Ser', position=473))
         self.assert_has_node(expected_node)
-        self.assertEqual('p(HGNC:AKT1, pmod(Ph, Ser, 473))', self.graph.node_to_bel(expected_node))
+        self.assertEqual(
+            'p(HGNC:AKT1, pmod(go:0006468 ! "protein phosphorylation", Ser, 473))',
+            self.graph.node_to_bel(expected_node),
+        )
 
         self.assert_has_node(parent)
         self.assert_has_edge(parent, expected_node, relation=HAS_VARIANT)
@@ -938,7 +944,10 @@ class TestProtein(TestTokenParserBase):
         parent = protein('HGNC', 'AKT1')
         expected_node = parent.with_variants(pmod('Ph', code='Ser', position=473))
         self.assert_has_node(expected_node)
-        self.assertEqual('p(HGNC:AKT1, pmod(Ph, Ser, 473))', self.graph.node_to_bel(expected_node))
+        self.assertEqual(
+            'p(HGNC:AKT1, pmod(go:0006468 ! "protein phosphorylation", Ser, 473))',
+            self.graph.node_to_bel(expected_node),
+        )
 
         self.assert_has_node(parent)
         self.assert_has_edge(parent, expected_node, relation=HAS_VARIANT)
@@ -964,7 +973,10 @@ class TestProtein(TestTokenParserBase):
         parent = protein('HGNC', 'HRAS')
         expected_node = parent.with_variants(pmod('Palm'))
         self.assert_has_node(expected_node)
-        self.assertEqual('p(HGNC:HRAS, pmod(Palm))', self.graph.node_to_bel(expected_node))
+        self.assertEqual(
+            'p(HGNC:HRAS, pmod(go:0018345 ! "protein palmitoylation"))',
+            self.graph.node_to_bel(expected_node),
+        )
 
         self.assert_has_node(parent)
         self.assert_has_edge(parent, expected_node, relation=HAS_VARIANT)
@@ -1540,7 +1552,7 @@ class TestActivity(TestTokenParserBase):
         statement = 'act(p(HGNC:AKT1))'
         result = self.parser.activity.parseString(statement)
 
-        expected_result = [ACTIVITY, [PROTEIN, ['HGNC', 'AKT1']]]
+        expected_result = [ACTIVITY, PROTEIN, ['HGNC', 'AKT1']]
         self.assertEqual(expected_result, result.asList())
 
         mod = modifier_po_to_dict(result)
@@ -1556,16 +1568,11 @@ class TestActivity(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'kin',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE,
-            },
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'AKT1',
-                },
+            EFFECT: activity_mapping['kin'],
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'AKT1',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1573,10 +1580,7 @@ class TestActivity(TestTokenParserBase):
         mod = modifier_po_to_dict(result)
         expected_mod = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'kin',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE,
-            },
+            EFFECT: activity_mapping['kin'],
         }
         self.assertEqual(expected_mod, mod)
 
@@ -1587,16 +1591,11 @@ class TestActivity(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'cat',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE
-            },
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'AKT1',
-                },
+            EFFECT: activity_mapping['cat'],
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'AKT1',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1604,10 +1603,7 @@ class TestActivity(TestTokenParserBase):
         mod = modifier_po_to_dict(result)
         expected_mod = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'cat',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE
-            },
+            EFFECT: activity_mapping['cat'],
         }
         self.assertEqual(expected_mod, mod)
 
@@ -1620,14 +1616,12 @@ class TestActivity(TestTokenParserBase):
             MODIFIER: ACTIVITY,
             EFFECT: {
                 NAMESPACE: 'GO',
-                NAME: 'catalytic activity'
+                NAME: 'catalytic activity',
             },
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'AKT1',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'AKT1',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1649,16 +1643,11 @@ class TestActivity(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'kin',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE
-            },
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'AKT1',
-                },
+            EFFECT: activity_mapping['kin'],
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'AKT1',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1666,10 +1655,7 @@ class TestActivity(TestTokenParserBase):
         mod = modifier_po_to_dict(result)
         expected_mod = {
             MODIFIER: ACTIVITY,
-            EFFECT: {
-                NAME: 'kin',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE
-            },
+            EFFECT: activity_mapping['kin'],
         }
         self.assertEqual(expected_mod, mod)
 
@@ -1723,12 +1709,10 @@ class TestTranslocationPermissive(unittest.TestCase):
 
         expected_dict = {
             MODIFIER: TRANSLOCATION,
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'EGFR',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'EGFR',
             },
         }
 
@@ -1754,7 +1738,7 @@ class TestTranslocationPermissive(unittest.TestCase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: ABUNDANCE,
                 CONCEPT: {
                     NAMESPACE: 'CHEBI',
@@ -1762,13 +1746,11 @@ class TestTranslocationPermissive(unittest.TestCase):
                 },
             },
             RELATION: DIRECTLY_INCREASES,
-            OBJECT: {
-                TARGET: {
-                    FUNCTION: ABUNDANCE,
-                    CONCEPT: {
-                        NAMESPACE: 'CHEBI',
-                        NAME: 'calcium(2+)',
-                    },
+            TARGET: {
+                FUNCTION: ABUNDANCE,
+                CONCEPT: {
+                    NAMESPACE: 'CHEBI',
+                    NAME: 'calcium(2+)',
                 },
                 MODIFIER: TRANSLOCATION,
             }
@@ -1783,7 +1765,7 @@ class TestTranslocationPermissive(unittest.TestCase):
 
         expected_annotations = {
             RELATION: DIRECTLY_INCREASES,
-            OBJECT: {
+            TARGET_MODIFIER: {
                 MODIFIER: TRANSLOCATION,
             }
         }
@@ -1801,17 +1783,15 @@ class TestTransformation(TestTokenParserBase):
         statement = 'deg(p(HGNC:AKT1))'
         result = self.parser.transformation.parseString(statement)
 
-        expected_result = [DEGRADATION, [PROTEIN, ['HGNC', 'AKT1']]]
+        expected_result = [DEGRADATION, PROTEIN, ['HGNC', 'AKT1']]
         self.assertEqual(expected_result, result.asList())
 
         expected_dict = {
             MODIFIER: DEGRADATION,
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'AKT1',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'AKT1',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1829,12 +1809,10 @@ class TestTransformation(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: DEGRADATION,
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'EGFR',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'EGFR',
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -1855,12 +1833,10 @@ class TestTransformation(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: TRANSLOCATION,
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'EGFR',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'EGFR',
             },
             EFFECT: {
                 FROM_LOC: {NAMESPACE: 'GO', NAME: 'cell surface', },
@@ -1888,12 +1864,10 @@ class TestTransformation(TestTokenParserBase):
 
         expected_dict = {
             MODIFIER: TRANSLOCATION,
-            TARGET: {
-                FUNCTION: PROTEIN,
-                CONCEPT: {
-                    NAMESPACE: 'HGNC',
-                    NAME: 'EGFR',
-                },
+            FUNCTION: PROTEIN,
+            CONCEPT: {
+                NAMESPACE: 'HGNC',
+                NAME: 'EGFR',
             },
             EFFECT: {
                 FROM_LOC: {NAMESPACE: 'GO', NAME: 'cell surface'},
@@ -1926,7 +1900,7 @@ class TestTransformation(TestTokenParserBase):
         statement = 'sec(p(HGNC:EGFR))'
         result = self.parser.transformation.parseString(statement)
 
-        expected_result = ['CellSecretion', [PROTEIN, ['HGNC', 'EGFR']]]
+        expected_result = [CELL_SECRETION, PROTEIN, ['HGNC', 'EGFR']]
         self.assertEqual(expected_result, result.asList())
 
         mod = modifier_po_to_dict(result)
@@ -1941,7 +1915,7 @@ class TestTransformation(TestTokenParserBase):
         statement = 'surf(p(HGNC:EGFR))'
         result = self.parser.transformation.parseString(statement)
 
-        expected_result = ['CellSurfaceExpression', [PROTEIN, ['HGNC', 'EGFR']]]
+        expected_result = [CELL_SURFACE_EXPRESSION, PROTEIN, ['HGNC', 'EGFR']]
         self.assertEqual(expected_result, result.asList())
 
         expected_mod = cell_surface_expression()
