@@ -101,16 +101,16 @@ class TestStruct(unittest.TestCase):
         test_str = """---------------------  -------------------
 Name                   Sialic Acid Graph
 Version                1.0.0
-Author                 Charles Tapley Hoyt
+Authors                Charles Tapley Hoyt
 Number of Nodes        9
 Number of Namespaces   3
 Number of Edges        11
 Number of Annotations  2
 Number of Citations    1
 Number of Authors      0
-Network Density        1.53E-01
 Number of Components   1
 Number of Warnings     0
+Network Density        1.53E-01
 ---------------------  -------------------
 
 Type (3)      Count
