@@ -6,7 +6,7 @@ import unittest
 
 from pybel import BELGraph
 from pybel.constants import (
-    ANNOTATIONS, CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_IDENTIFIER, CITATION_DB, CITATION_TYPE_PUBMED,
+    ANNOTATIONS, CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_TYPE_PUBMED, IDENTIFIER, NAMESPACE,
 )
 from pybel.dsl import protein
 from pybel.examples import sialic_acid_graph
@@ -25,6 +25,7 @@ class TestMetadata(unittest.TestCase):
         y = protein(namespace='HGNC', name='X')
 
         graph = BELGraph()
+        graph.annotation_list['A'] = set('ABC')
         key = graph.add_increases(
             x,
             y,
@@ -85,6 +86,7 @@ class TestMetadata(unittest.TestCase):
         y = protein(namespace='HGNC', name='X')
 
         graph = BELGraph()
+        graph.annotation_list['A'] = set('ABC')
 
         k0 = graph.add_part_of(x, y)
         k1 = graph.add_increases(
@@ -100,8 +102,8 @@ class TestMetadata(unittest.TestCase):
             x,
             y,
             citation={
-                CITATION_DB: CITATION_TYPE_PUBMED,
-                CITATION_IDENTIFIER: '12345678',
+                NAMESPACE: CITATION_TYPE_PUBMED,
+                IDENTIFIER: '12345678',
                 CITATION_DATE: '2018-12-10',
             },
             evidence='Fake',
@@ -116,7 +118,7 @@ class TestMetadata(unittest.TestCase):
 
         for k in k1, k2:
             self.assertIn(CITATION, graph[x][y][k])
-            self.assertIn(CITATION_DB, graph[x][y][k][CITATION])
-            self.assertIn(CITATION_IDENTIFIER, graph[x][y][k][CITATION])
+            self.assertIn(NAMESPACE, graph[x][y][k][CITATION])
+            self.assertIn(IDENTIFIER, graph[x][y][k][CITATION])
             self.assertNotIn(CITATION_DATE, graph[x][y][k][CITATION])
             self.assertNotIn(CITATION_AUTHORS, graph[x][y][k][CITATION])
